#!/bin/sh
### Check WHIZARD for a simple NLO process with dummy virtual matrix-elements and combined integration
echo "Running script $0"
if test -f OCAML_FLAG; then
    name=`basename @script@`
    ./run_whizard.sh @script@ --no-logging
    cat ${name}_p1_fks_regions.out >> $name.log
    diff ref-output/$name.ref $name.log
else
    echo "|=============================================================================|"
    echo "No O'Mega matrix elements available, test skipped"
    exit 77
fi
